@@ -323,7 +323,7 @@ class Schema2RQLTC(TestCase):
               'internationalizable': True,
               'fulltextindexed': False,
               'ordernum': 3,
-              'defaultval': Binary('text/plain'),
+              'defaultval': Binary.zpickle(u'text/plain'),
               'indexed': False,
               'cardinality': u'?1'}),
             ('INSERT CWConstraint X: X value %(value)s, X cstrtype CT, EDEF constrained_by X '
@@ -339,7 +339,6 @@ class Schema2RQLTC(TestCase):
                              list(rdef2rql(schema['description_format'].rdefs[('CWRType', 'String')],
                                            cstrtypemap)))
 
-
     def test_updateeschema2rql1(self):
         self.assertListEqual([('SET X description %(description)s,X final %(final)s,'
                                'X name %(name)s WHERE X eid %(x)s',
