@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""basic support for SIMILE's timline widgets
+"""basic support for SIMILE's timeline widgets
 
 cf. http://code.google.com/p/simile-widgets/
 """
